Crate ziyy_core

Crate ziyy_core 

Ziyy’s core library

Ziyy is a markup language that allows you to style your terminal using HTML-like syntax.

For information on using Ziyy, see the Ziyy website.

Usage

use ziyy_core::style;

let styled = style("<b>Lorem
    <d> dolor sit
        <b>amet consectetur
            <d>adipiscing elit</d>
            quisque
        </b>faucibus ex sapien.");

Feature flags

  • unstable Can break or be removed at any time without warning.
  • parallel Enables parallel parsing.

Structs

Ansiunstable
Ansi4Bitunstable
Ansi256unstable
AnsiOptionsunstable
Chunkunstable
Documentunstable
Error
Represents an error with additional context such as its type, message, and location.
Fragmentunstable
Indexerunstable
The Indexer adds indices to empty placeholders
Nodeunstable
Parserunstable
Position
A position in source code.
Resolverunstable
Rgbunstable
Span
A span in source code.
Splitterunstable
Tagunstable
TagParserunstable

Enums

ChunkDataunstable
Colorunstable
DuoEffectunstable
Two Effects that are cleared by same ansi sequence and only one can be set at a time.
Effectunstable
Ansi effect
ErrorType
Represents the various types of errors that can occur.
FragmentTypeunstable
TagTypeunstable

Statics

WORD_PARSERunstable

Functions

style
Styles the given text using ziyy.
try_style
Styles the given text using ziyy.

Type Aliases

Result
A type alias for results that return an Error on failure.