Ziyy’s core library
Ziyy is a markup language that allows you to style your terminal using HTML-like syntax.
For information on using Ziyy, see the Ziyy website.
Usage
use ziyy_core::style;
let styled = style("<b>Lorem
<d> dolor sit
<b>amet consectetur
<d>adipiscing elit</d>
quisque
</b>faucibus ex sapien.");Feature flags
unstableCan break or be removed at any time without warning.parallelEnables parallel parsing.
Structs
- Ansi
unstable - Ansi4
Bit unstable - Ansi256
unstable - Ansi
Options unstable - Chunk
unstable - Document
unstable - Error
- Represents an error with additional context such as its type, message, and location.
- Fragment
unstable - Indexer
unstable - The Indexer adds indices to empty placeholders
- Node
unstable - Parser
unstable - Position
- A position in source code.
- Resolver
unstable - Rgb
unstable - Span
- A span in source code.
- Splitter
unstable - Tag
unstable - TagParser
unstable
Enums
- Chunk
Data unstable - Color
unstable - DuoEffect
unstable - Two Effects that are cleared by same ansi sequence and only one can be set at a time.
- Effect
unstable - Ansi effect
- Error
Type - Represents the various types of errors that can occur.
- Fragment
Type unstable - TagType
unstable
Statics
- WORD_
PARSER unstable
Functions
Type Aliases
- Result
- A type alias for results that return an
Erroron failure.